==> plw_1.10.0.zip: plw/doc/HowToPLW.R <==
###################################################
### chunk number 1: 
###################################################
#line 45 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
require(plw)


###################################################
### chunk number 2: 
###################################################
#line 68 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
data(AffySpikeU95Subset)


###################################################
### chunk number 3: 
###################################################
#line 71 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
AffySpikeU95Subset


###################################################
### chunk number 4: 
###################################################
#line 80 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
pData(AffySpikeU95Subset)


###################################################
### chunk number 5: 
###################################################
#line 85 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
group<-factor(rep(letters[1:2],each=3))
design<-model.matrix(~group-1)
contrast<-matrix(c(1,-1),1,2)


###################################################
### chunk number 6: 
###################################################
#line 90 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
design
contrast


###################################################
### chunk number 7: 
###################################################
#line 95 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
plwFit<-plw(AffySpikeU95Subset,design=design,contrast=contrast,epsilon=1e-05)


###################################################
### chunk number 8: 
###################################################
#line 98 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
plwFit


###################################################
### chunk number 9: 
###################################################
#line 116 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
topRankSummary(plwFit,genes=spikedProbesU95)


###################################################
### chunk number 10: 
###################################################
#line 120 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
topRankSummary(plwFit,genesOfRank=11:20)


###################################################
### chunk number 11: 
###################################################
#line 125 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
topRankSummary(plwFit,nGenes=20)


###################################################
### chunk number 12: 
###################################################
#line 135 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
plotSummaryT(plwFit,genes=spikedProbesU95)


###################################################
### chunk number 13: 
###################################################
#line 143 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
plotSummaryLog2FC(plwFit,nGenes=15)


###################################################
### chunk number 14: 
###################################################
#line 162 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
varHistPlot(plwFit)


###################################################
### chunk number 15: 
###################################################
#line 171 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
scaleParameterPlot(plwFit)


###################################################
### chunk number 16:  eval=FALSE
###################################################
## #line 188 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
## source("http://www.math.chalmers.se/~astrandm/plw/GetApoAIdata.R")
## RG <- GetApoAIdata()
## require(limma)
## MA <- normalizeWithinArrays(RG)
## rownames(MA$M) <- MA$genes$Name
## ii <- apply(is.na(MA$M),1,any)
## MA$A <- MA$A[!ii,]
## MA$M <- MA$M[!ii,]


###################################################
### chunk number 17:  eval=FALSE
###################################################
## #line 202 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
## design <- cbind("Control-Ref"=1,"KO-Control"=MA$targets$Cy5=="ApoAI KO")
## contrast <- matrix(0:1,ncol=2)


###################################################
### chunk number 18:  eval=FALSE
###################################################
## #line 206 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
## design
## contrast


###################################################
### chunk number 19:  eval=FALSE
###################################################
## #line 216 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
## meanX <- apply(MA$A,1,mean)
## knots <- quantile(meanX,seq(0.1,0.9,by=0.2))
## lmwFit <- lmw(MA$M,design=design,contrast=contrast,meanX=meanX,knots=knots)


###################################################
### chunk number 20:  eval=FALSE
###################################################
## #line 221 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
## lmwFit


###################################################
### chunk number 21:  eval=FALSE
###################################################
## #line 225 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpND5tU5/R.INSTALL1db141e0/plw/inst/doc/HowToPLW.Rnw"
## topRankSummary(lmwFit,nGenes=10)

==> plw_1.12.0.zip: plw/doc/HowToPLW.R <==
###################################################
### chunk number 1: 
###################################################
#line 45 "HowToPLW.Rnw"
require(plw)


###################################################
### chunk number 2: 
###################################################
#line 68 "HowToPLW.Rnw"
data(AffySpikeU95Subset)


###################################################
### chunk number 3: 
###################################################
#line 71 "HowToPLW.Rnw"
AffySpikeU95Subset


###################################################
### chunk number 4: 
###################################################
#line 80 "HowToPLW.Rnw"
pData(AffySpikeU95Subset)


###################################################
### chunk number 5: 
###################################################
#line 85 "HowToPLW.Rnw"
group<-factor(rep(letters[1:2],each=3))
design<-model.matrix(~group-1)
contrast<-matrix(c(1,-1),1,2)


###################################################
### chunk number 6: 
###################################################
#line 90 "HowToPLW.Rnw"
design
contrast


###################################################
### chunk number 7: 
###################################################
#line 95 "HowToPLW.Rnw"
plwFit<-plw(AffySpikeU95Subset,design=design,contrast=contrast,epsilon=1e-05)


###################################################
### chunk number 8: 
###################################################
#line 98 "HowToPLW.Rnw"
plwFit


###################################################
### chunk number 9: 
###################################################
#line 116 "HowToPLW.Rnw"
topRankSummary(plwFit,genes=spikedProbesU95)


###################################################
### chunk number 10: 
###################################################
#line 120 "HowToPLW.Rnw"
topRankSummary(plwFit,genesOfRank=11:20)


###################################################
### chunk number 11: 
###################################################
#line 125 "HowToPLW.Rnw"
topRankSummary(plwFit,nGenes=20)


###################################################
### chunk number 12: 
###################################################
#line 135 "HowToPLW.Rnw"
plotSummaryT(plwFit,genes=spikedProbesU95)


###################################################
### chunk number 13: 
###################################################
#line 143 "HowToPLW.Rnw"
plotSummaryLog2FC(plwFit,nGenes=15)


###################################################
### chunk number 14: 
###################################################
#line 162 "HowToPLW.Rnw"
varHistPlot(plwFit)


###################################################
### chunk number 15: 
###################################################
#line 171 "HowToPLW.Rnw"
scaleParameterPlot(plwFit)


###################################################
### chunk number 16:  eval=FALSE
###################################################
## #line 188 "HowToPLW.Rnw"
## source("http://www.math.chalmers.se/~astrandm/plw/GetApoAIdata.R")
## RG <- GetApoAIdata()
## require(limma)
## MA <- normalizeWithinArrays(RG)
## rownames(MA$M) <- MA$genes$Name
## ii <- apply(is.na(MA$M),1,any)
## MA$A <- MA$A[!ii,]
## MA$M <- MA$M[!ii,]


###################################################
### chunk number 17:  eval=FALSE
###################################################
## #line 202 "HowToPLW.Rnw"
## design <- cbind("Control-Ref"=1,"KO-Control"=MA$targets$Cy5=="ApoAI KO")
## contrast <- matrix(0:1,ncol=2)


###################################################
### chunk number 18:  eval=FALSE
###################################################
## #line 206 "HowToPLW.Rnw"
## design
## contrast


###################################################
### chunk number 19:  eval=FALSE
###################################################
## #line 216 "HowToPLW.Rnw"
## meanX <- apply(MA$A,1,mean)
## knots <- quantile(meanX,seq(0.1,0.9,by=0.2))
## lmwFit <- lmw(MA$M,design=design,contrast=contrast,meanX=meanX,knots=knots)


###################################################
### chunk number 20:  eval=FALSE
###################################################
## #line 221 "HowToPLW.Rnw"
## lmwFit


###################################################
### chunk number 21:  eval=FALSE
###################################################
## #line 225 "HowToPLW.Rnw"
## topRankSummary(lmwFit,nGenes=10)
